Esmlab (Earth System Model Lab)
================================

.. image:: https://img.shields.io/circleci/project/github/NCAR/esmlab/master.svg?style=for-the-badge&logo=circleci
    :target: https://circleci.com/gh/NCAR/esmlab/tree/master

.. image:: https://img.shields.io/codecov/c/github/NCAR/esmlab.svg?style=for-the-badge
    :target: https://codecov.io/gh/NCAR/esmlab


.. image:: https://img.shields.io/readthedocs/esmlab/latest.svg?style=for-the-badge
    :target: https://esmlab.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/esmlab.svg?style=for-the-badge
    :target: https://pypi.org/project/esmlab
    :alt: Python Package Index
    
.. image:: https://img.shields.io/conda/vn/conda-forge/esmlab.svg?style=for-the-badge
    :target: https://anaconda.org/conda-forge/esmlab
    :alt: Conda Version



Tools for working with earth system multi-model analyses with xarray. See
documentation_ for more information.

.. _documentation: https://esmlab.readthedocs.io/en/latest/
